#ifndef LIBBCC_VERSION_H
#define LIBBCC_VERSION_H

#define LIBBCC_VERSION "0.36.1"
#define LIBBCC_MAJOR_VERSION 0
#define LIBBCC_MINOR_VERSION 36
#define LIBBCC_PATCH_VERSION 1

#define __LIBBCC_VERSION(a, b, c) (((a) << 16) + ((b) << 8) + ((c) > 255 ? 255 : (c)))
#define LIBBCC_VERSION_CODE __LIBBCC_VERSION(LIBBCC_MAJOR_VERSION, LIBBCC_MINOR_VERSION, LIBBCC_PATCH_VERSION)
#define LIBBCC_VERSION_GEQ(a,b,c) LIBBCC_VERSION_CODE >= __LIBBCC_VERSION(a, b, c)

#endif
